@@ -14,11 +14,16 @@
 // You should have received a copy of the GNU General Public License
 // along with the snarkVM library. If not, see <https://www.gnu.org/licenses/>.
 
-use crate::utilities::{alloc::AllocGadget, eq::EqGadget, uint::UInt8, ToBytesGadget};
 use snarkvm_algorithms::traits::SignatureScheme;
 use snarkvm_fields::Field;
 use snarkvm_r1cs::{errors::SynthesisError, ConstraintSystem};
 
+use crate::{
+    bits::ToBytesGadget,
+    integers::uint::UInt8,
+    traits::{alloc::AllocGadget, eq::EqGadget},
+};
+
 pub trait SignaturePublicKeyRandomizationGadget<S: SignatureScheme, F: Field> {
     type ParametersGadget: AllocGadget<S::Parameters, F>;
     type PublicKeyGadget: ToBytesGadget<F> + EqGadget<F> + AllocGadget<S::PublicKey, F> + Clone;
